import React from 'react';

interface Props {
  running: boolean;
  speed: number;
  width: number;
  height: number;
  toggle: () => void;
  updateSpeed: (speed: number) => void;
  updateDimensions: (dimensions: { width?: number; height?: number }) => void;
}

const Controls = (props: Props) => {
  const {
    running,
    speed,
    toggle,
    updateSpeed,
    width,
    height,
    updateDimensions,
  } = props;

  const goSlower = () => {
    updateSpeed(speed + 100);
  };

  const goFaster = () => {
    if (speed > 100) {
      updateSpeed(speed - 100);
    }
  };

  return (
    <div className="controls">
      <div className="controls__row --width">
        <label>
          Width{' '}
          <input
            type="number"
            value={width}
            onChange={(e) =>
              updateDimensions({ width: parseInt(e.currentTarget.value, 10) })
            }
          />
        </label>
        <label>
          Height{' '}
          <input
            type="number"
            value={height}
            onChange={(e) =>
              updateDimensions({ height: parseInt(e.currentTarget.value, 10) })
            }
          />
        </label>
      </div>
      <div className="controls__row">
        <button onClick={toggle}>{running ? 'Pause' : 'Play'}</button>
        <div className="speed">
          <button onClick={goSlower}>Slower</button>
          <button disabled={speed <= 100} onClick={goFaster}>
            Faster
          </button>
          <span>{speed}ms</span>
        </div>
      </div>
    </div>
  );
};

export default Controls;
